==> EMBOSS-2.5.1.tar.gz: EMBOSS-2.5.1/emboss/noreturn.c <==
/* @source noreturn application
**
** Remove trailing carriage returns from otherwise ASCII files
**
** @author: Copyright (C) Alan Bleasby (ableasby@hgmp.mrc.ac.uk)
** @@
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 2
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
******************************************************************************/

#include "emboss.h"



/* @prog noreturn *************************************************************
**
** Removes carriage return from ASCII files
**
******************************************************************************/

int main(int argc, char **argv)
{
    AjPFile inf  = NULL;
    AjPFile outf = NULL;
    AjPStr  line = NULL;
    ajint   len;
    ajint i;
    char    *p;

    embInit("noreturn", argc, argv);

    inf  = ajAcdGetInfile("infile");
    outf = ajAcdGetOutfile("outfile");

    line = ajStrNew();

    while(ajFileReadLine(inf,&line))
    {
	p   = MAJSTRSTR(line);
	len = ajStrLen(line);
	if(len)
	{
	  if(p[len-1] == 0x0d)
	  {
	    p[len-1] = 0x00;
	  }

	  /* for files with 0d but no newline,
	  ** we have everything in one line
	  ** so we should replace the rest directly
	  */

	  for (i=0;i<len;i++)
	  {
	    if (p[i] ==  0x0d)
	    {
	      p[i] = 0x0a;
	    }
	  }
	}

	ajFmtPrintF(outf,"%s\n",p);
    }

    ajStrDel(&line);
    ajFileClose(&inf);
    ajFileClose(&outf);

    ajExit();
    return 0;
}

==> EMBOSS-2.9.0.tar.gz: EMBOSS-2.9.0/emboss/noreturn.c <==
/* @source noreturn application
**
** Remove trailing carriage returns from otherwise ASCII files
**
** @author: Copyright (C) Alan Bleasby (ableasby@hgmp.mrc.ac.uk)
** @@
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 2
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
******************************************************************************/

#include "emboss.h"




/* @prog noreturn *************************************************************
**
** Removes carriage return from ASCII files
**
******************************************************************************/

int main(int argc, char **argv)
{
    AjPFile inf  = NULL;
    AjPFile outf = NULL;
    AjPStr  line = NULL;
    ajint   len;
    ajint i;
    char    *p;

    embInit("noreturn", argc, argv);

    inf  = ajAcdGetInfile("infile");
    outf = ajAcdGetOutfile("outfile");

    line = ajStrNew();

    while(ajFileReadLine(inf,&line))
    {
	p   = MAJSTRSTR(line);
	len = ajStrLen(line);
	if(len)
	{
	    if(p[len-1] == 0x0d)
		p[len-1] = 0x00;

	    /* for files with 0d but no newline,
	    ** there's everything in one line
	    ** so replace the rest directly
	    */

	    for(i=0;i<len;i++)
		if(p[i] ==  0x0d)
		    p[i] = 0x0a;
	}
	
	ajFmtPrintF(outf,"%s\n",p);
    }
    
    ajStrDel(&line);
    ajFileClose(&inf);
    ajFileClose(&outf);

    ajExit();

    return 0;
}
